# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'urssus/ui/feed_properties.ui'
#
# Created: Sun Jul 27 21:58:01 2008
#      by: PyQt4 UI code generator 4.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(387,287)
        self.verticalLayout_2 = QtGui.QVBoxLayout(Dialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtGui.QTabWidget(Dialog)
        self.tabWidget.setObjectName("tabWidget")
        self.general = QtGui.QWidget()
        self.general.setGeometry(QtCore.QRect(0,0,365,200))
        self.general.setObjectName("general")
        self.verticalLayout = QtGui.QVBoxLayout(self.general)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout = QtGui.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.url = QtGui.QLineEdit(self.general)
        self.url.setObjectName("url")
        self.gridLayout.addWidget(self.url,1,1,1,1)
        self.label_2 = QtGui.QLabel(self.general)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2,1,0,1,1)
        self.label = QtGui.QLabel(self.general)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label,0,0,1,1)
        self.name = QtGui.QLineEdit(self.general)
        self.name.setObjectName("name")
        self.gridLayout.addWidget(self.name,0,1,1,1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.notify = QtGui.QCheckBox(self.general)
        self.notify.setObjectName("notify")
        self.verticalLayout.addWidget(self.notify)
        self.customUpdate = QtGui.QCheckBox(self.general)
        self.customUpdate.setObjectName("customUpdate")
        self.verticalLayout.addWidget(self.customUpdate)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_3 = QtGui.QLabel(self.general)
        self.label_3.setEnabled(False)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.updatePeriod = QtGui.QSpinBox(self.general)
        self.updatePeriod.setEnabled(False)
        self.updatePeriod.setMinimum(1)
        self.updatePeriod.setMaximum(500)
        self.updatePeriod.setObjectName("updatePeriod")
        self.horizontalLayout.addWidget(self.updatePeriod)
        self.updateUnit = QtGui.QComboBox(self.general)
        self.updateUnit.setEnabled(False)
        self.updateUnit.setObjectName("updateUnit")
        self.horizontalLayout.addWidget(self.updateUnit)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem = QtGui.QSpacerItem(20,40,QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.tabWidget.addTab(self.general,"")
        self.archive = QtGui.QWidget()
        self.archive.setGeometry(QtCore.QRect(0,0,365,200))
        self.archive.setObjectName("archive")
        self.verticalLayout_3 = QtGui.QVBoxLayout(self.archive)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.gridLayout_2 = QtGui.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.useDefault = QtGui.QRadioButton(self.archive)
        self.useDefault.setChecked(True)
        self.useDefault.setObjectName("useDefault")
        self.gridLayout_2.addWidget(self.useDefault,0,0,1,2)
        self.keepAll = QtGui.QRadioButton(self.archive)
        self.keepAll.setObjectName("keepAll")
        self.gridLayout_2.addWidget(self.keepAll,1,0,1,2)
        self.limitCount = QtGui.QRadioButton(self.archive)
        self.limitCount.setObjectName("limitCount")
        self.gridLayout_2.addWidget(self.limitCount,2,0,1,1)
        self.count = QtGui.QSpinBox(self.archive)
        self.count.setEnabled(False)
        self.count.setObjectName("count")
        self.gridLayout_2.addWidget(self.count,2,1,1,1)
        self.limitDays = QtGui.QRadioButton(self.archive)
        self.limitDays.setObjectName("limitDays")
        self.gridLayout_2.addWidget(self.limitDays,3,0,1,1)
        self.days = QtGui.QSpinBox(self.archive)
        self.days.setEnabled(False)
        self.days.setObjectName("days")
        self.gridLayout_2.addWidget(self.days,3,1,1,1)
        self.noArchive = QtGui.QRadioButton(self.archive)
        self.noArchive.setObjectName("noArchive")
        self.gridLayout_2.addWidget(self.noArchive,4,0,1,2)
        self.verticalLayout_3.addLayout(self.gridLayout_2)
        spacerItem1 = QtGui.QSpacerItem(20,40,QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.tabWidget.addTab(self.archive,"")
        self.advanced = QtGui.QWidget()
        self.advanced.setGeometry(QtCore.QRect(0,0,365,200))
        self.advanced.setObjectName("advanced")
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.advanced)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.loadFull = QtGui.QCheckBox(self.advanced)
        self.loadFull.setObjectName("loadFull")
        self.verticalLayout_4.addWidget(self.loadFull)
        self.markRead = QtGui.QCheckBox(self.advanced)
        self.markRead.setObjectName("markRead")
        self.verticalLayout_4.addWidget(self.markRead)
        spacerItem2 = QtGui.QSpacerItem(20,123,QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem2)
        self.tabWidget.addTab(self.advanced,"")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.buttonBox = QtGui.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)
        self.label_2.setBuddy(self.url)
        self.label.setBuddy(self.name)
        self.label_3.setBuddy(self.updatePeriod)

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QObject.connect(self.buttonBox,QtCore.SIGNAL("accepted()"),Dialog.accept)
        QtCore.QObject.connect(self.buttonBox,QtCore.SIGNAL("rejected()"),Dialog.reject)
        QtCore.QObject.connect(self.limitCount,QtCore.SIGNAL("toggled(bool)"),self.count.setEnabled)
        QtCore.QObject.connect(self.limitDays,QtCore.SIGNAL("toggled(bool)"),self.days.setEnabled)
        QtCore.QObject.connect(self.customUpdate,QtCore.SIGNAL("toggled(bool)"),self.updatePeriod.setEnabled)
        QtCore.QObject.connect(self.customUpdate,QtCore.SIGNAL("toggled(bool)"),self.updateUnit.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("Dialog", "&URL:", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("Dialog", "&Name:", None, QtGui.QApplication.UnicodeUTF8))
        self.notify.setText(QtGui.QApplication.translate("Dialog", "Notify when new articles arri&ve", None, QtGui.QApplication.UnicodeUTF8))
        self.customUpdate.setText(QtGui.QApplication.translate("Dialog", "U&se a custom update interval", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("Dialog", "Update &every", None, QtGui.QApplication.UnicodeUTF8))
        self.updateUnit.addItem(QtGui.QApplication.translate("Dialog", "Minutes", None, QtGui.QApplication.UnicodeUTF8))
        self.updateUnit.addItem(QtGui.QApplication.translate("Dialog", "Hours", None, QtGui.QApplication.UnicodeUTF8))
        self.updateUnit.addItem(QtGui.QApplication.translate("Dialog", "Days", None, QtGui.QApplication.UnicodeUTF8))
        self.updateUnit.addItem(QtGui.QApplication.translate("Dialog", "Never", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.general), QtGui.QApplication.translate("Dialog", "&General", None, QtGui.QApplication.UnicodeUTF8))
        self.useDefault.setText(QtGui.QApplication.translate("Dialog", "&Use default settings", None, QtGui.QApplication.UnicodeUTF8))
        self.keepAll.setText(QtGui.QApplication.translate("Dialog", "&Keep all articles", None, QtGui.QApplication.UnicodeUTF8))
        self.limitCount.setText(QtGui.QApplication.translate("Dialog", "Limit archi&ve to:", None, QtGui.QApplication.UnicodeUTF8))
        self.count.setSuffix(QtGui.QApplication.translate("Dialog", " articles", None, QtGui.QApplication.UnicodeUTF8))
        self.limitDays.setText(QtGui.QApplication.translate("Dialog", "&Delete older than:", None, QtGui.QApplication.UnicodeUTF8))
        self.days.setSuffix(QtGui.QApplication.translate("Dialog", " days", None, QtGui.QApplication.UnicodeUTF8))
        self.noArchive.setText(QtGui.QApplication.translate("Dialog", "Di&sable archiving", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.archive), QtGui.QApplication.translate("Dialog", "&Archive", None, QtGui.QApplication.UnicodeUTF8))
        self.loadFull.setText(QtGui.QApplication.translate("Dialog", "&Load the full website when reading articles", None, QtGui.QApplication.UnicodeUTF8))
        self.markRead.setText(QtGui.QApplication.translate("Dialog", "&Mark articles as read when they arrive", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.advanced), QtGui.QApplication.translate("Dialog", "A&dvanced", None, QtGui.QApplication.UnicodeUTF8))

